==> tkabber_0.10.0.orig.tar.gz: tkabber-0.10.0/plugins/roster/roster_delimiter.tcl <==
# $Id: roster_delimiter.tcl 753 2006-10-09 20:24:44Z sergei $
#
# Nested roster groups server-side delimiter storing (XEP-0083).
#

###############################################################################

namespace eval delimiter {}

###############################################################################
#
# Retrieving nested groups delimiter
#

proc delimiter::request {connid fallback args} {
    debugmsg plugins "delimiter::request $connid $fallback $args"
    
    set command ""
    foreach {key val} $args {
	switch -- $key {
	    -command { set command $val }
	}
    }
    
    jlib::send_iq get \
	[jlib::wrapper:createtag query \
	     -vars [list xmlns $::NS(private)] \
	     -subtags [list [jlib::wrapper:createtag roster \
				 -vars [list xmlns $::NS(delimiter)]]]] \
	-command [list [namespace current]::request_result \
		       $connid $fallback $command] \
	-connection $connid
}

proc delimiter::request_result {connid fallback command res child} {
    debugmsg plugins "delimiter::request_result $connid $res"

    set delimiter $fallback

    if {$res == "OK"} {
	jlib::wrapper:splitxml $child tag vars isempty cdata children

	foreach ch $children {
	    jlib::wrapper:splitxml $ch tag1 vars1 isempty1 cdata1 children1

	    if {[jlib::wrapper:getattr $vars1 xmlns] == $NS(delimiter)} {
		set delimiter $cdata1
	    }
	}
    }

    if {$command != ""} {
	eval $command [list $connid $delimiter]
    }
}

###############################################################################
#
# Storing nested groups delimiter
#

proc delimiter::store {connid delimiter args} {
    debugmsg plugins "delimiter::store $connid $delimiter $args"

    set command ""
    foreach {key val} $args {
	switch -- $key {
	    -command { set command $val }
	}
    }
    
    jlib::send_iq set \
	[jlib::wrapper:createtag query \
	     -vars [list xmlns $::NS(private)] \
	     -subtags [list [jlib::wrapper:createtag roster \
				 -vars [list xmlns $::NS(delimiter)] \
				 -chdata $delimiter]]] \
	-command [list [namespace current]::store_result $connid $command] \
	-connection $connid
    
}

proc delimiter::store_result {connid command res child} {
    debugmsg plugins "delimiter::store_result $connid $res"
    
    if {$command != ""} {
	eval $command [list $res $child]
    }
}

==> tkabber_0.11.1.orig.tar.gz: tkabber-0.11.1/plugins/roster/roster_delimiter.tcl <==
# $Id: roster_delimiter.tcl 1237 2007-09-21 17:27:08Z sergei $
#
# Nested roster groups server-side delimiter storing (XEP-0083).
#

###############################################################################

namespace eval delimiter {}

###############################################################################
#
# Retrieving nested groups delimiter
#

proc delimiter::request {connid fallback args} {
    debugmsg plugins "delimiter::request $connid $fallback $args"
    
    set command ""
    foreach {key val} $args {
	switch -- $key {
	    -command { set command $val }
	}
    }

    private::retrieve [list [jlib::wrapper:createtag roster \
				 -vars [list xmlns $::NS(delimiter)]]] \
	-command [list [namespace current]::request_result \
		       $connid $fallback $command] \
	-connection $connid
}

proc delimiter::request_result {connid fallback command res child} {
    debugmsg plugins "delimiter::request_result $connid $res"

    set delimiter $fallback

    if {$res == "OK"} {
	foreach ch $child {
	    jlib::wrapper:splitxml $ch tag1 vars1 isempty1 cdata1 children1

	    if {[jlib::wrapper:getattr $vars1 xmlns] == $NS(delimiter)} {
		set delimiter $cdata1
	    }
	}
    }

    if {$command != ""} {
	eval $command [list $connid $delimiter]
    }
}

###############################################################################
#
# Storing nested groups delimiter
#

proc delimiter::store {connid delimiter args} {
    debugmsg plugins "delimiter::store $connid $delimiter $args"

    set command ""
    foreach {key val} $args {
	switch -- $key {
	    -command { set command $val }
	}
    }

    private::store [list [jlib::wrapper:createtag roster \
			      -vars [list xmlns $::NS(delimiter)] \
			      -chdata $delimiter]] \
	-command [list [namespace current]::store_result $connid $command] \
	-connection $connid
    
}

proc delimiter::store_result {connid command res child} {
    debugmsg plugins "delimiter::store_result $connid $res"
    
    if {$command != ""} {
	eval $command [list $res $child]
    }
}
